==> manage-1.1.32-2.jar: management/sqls/营收/报表管理/统计类/收费统计汇总表/get_balance.sql <==
//期初余额
select 
	f_gasproperties_type,
	f_gasproperties,
	SUM(f_money) f_money,
	SUM(f_haircut_gas) f_gas,
	SUM(f_haircut_money) money 
from(
		select 
			s.f_gasproperties_type,
			s.f_gasproperties,
			0 f_money,
			SUM(s1.f_surplus_gas_max)-SUM(isnull(s2.f_haircut_gas,0)) f_haircut_gas,
			(SUM(s1.f_surplus_gas_max)-SUM(isnull(s2.f_haircut_gas,0)))*1.98 f_haircut_money
		from (
			select 
				f_price_id,
				SUM(f_surplus_gas_max) f_surplus_gas_max
			from(
					select 
						f_price_id,
						f_userinfo_id,
						MIN(f_surplus_gas)+SUM(f_haircut_gas) f_surplus_gas_max
					from 
						V_handplan 
					where 
						f_meter_state='已抄表'	and		
						f_haircut_gas!=0 
					group by f_price_id,f_userinfo_id
			) g group by f_price_id
		) s1 left join (
			select 
					f_price_id,
					SUM(f_haircut_gas) f_haircut_gas
				from 
					V_handplan 
				where 
					 f_hand_date<dateadd(month,-1,'{startDate}') and
					f_meter_state='已抄表'	and		
					f_haircut_gas!=0 
				group by f_price_id
		) s2 on s1.f_price_id=s2.f_price_id
		left join (select * from t_stairprice where f_state='有效') s 
		on s1.f_price_id=s.f_price_id
		group by s.f_gasproperties_type,s.f_gasproperties
	union all
		select 
			 s2.f_gasproperties_type,
			 s2.f_gasproperties,
			 convert(decimal(18,2),sum(f_curbalance)) f_money,
			 0 f_haircut_gas,
			 0 f_haircut_money
		from 
			(select 
				f_userinfo_id,max(f_delivery_date) f_delivery_date
			from t_sellinggas 
			where  f_delivery_date<'{startDate}' 
					and  f_charge_state='有效'
			group by f_userinfo_id) s
			left join t_sellinggas s1 
			on s.f_userinfo_id=s1.f_userinfo_id and s.f_delivery_date=s1.f_delivery_date 
			left join (select * from t_stairprice where f_state='有效') s2 
			on s1.f_price_id=s2.f_price_id
		group by s1.f_price_id,s2.f_gasproperties_type,s2.f_gasproperties
) s group by 	f_gasproperties_type,f_gasproperties

==> manage-3.1.0-46.jar: management/sqls/营收/报表管理/统计类/收费统计汇总表/get_balance.sql <==
//期初余额
select 
	f_gasproperties_type,
	f_gasproperties,
	SUM(f_money) f_money,
	SUM(f_haircut_gas) f_gas,
	SUM(f_haircut_money) money 
from(
		select 
			s.f_gasproperties_type,
			s.f_gasproperties,
			0 f_money,
			SUM(s1.f_surplus_gas_max)-SUM(isnull(s2.f_haircut_gas,0)) f_haircut_gas,
			(SUM(s1.f_surplus_gas_max)-SUM(isnull(s2.f_haircut_gas,0)))*1.98 f_haircut_money
		from (
			select 
				f_price_id,
				SUM(f_surplus_gas_max) f_surplus_gas_max
			from(
					select 
						f_price_id,
						f_userinfo_id,
						MIN(f_surplus_gas)+SUM(f_haircut_gas) f_surplus_gas_max
					from 
						V_handplan 
					where 
						f_meter_state='已抄表'	and		
						f_haircut_gas!=0 
					group by f_price_id,f_userinfo_id
			) g group by f_price_id
		) s1 left join (
			select 
					f_price_id,
					SUM(f_haircut_gas) f_haircut_gas
				from 
					V_handplan 
				where 
					 f_hand_date<dateadd(month,-1,'{startDate}') and
					f_meter_state='已抄表'	and		
					f_haircut_gas!=0 
				group by f_price_id
		) s2 on s1.f_price_id=s2.f_price_id
		left join (select * from t_stairprice where f_state='有效') s 
		on s1.f_price_id=s.f_price_id
		group by s.f_gasproperties_type,s.f_gasproperties
	union all
		select 
			 s2.f_gasproperties_type,
			 s2.f_gasproperties,
			 convert(decimal(18,2),sum(f_curbalance)) f_money,
			 0 f_haircut_gas,
			 0 f_haircut_money
		from 
			(select 
				f_userinfo_id,max(f_operate_date) f_operate_date
			from t_sellinggas 
			where  f_operate_date<'{startDate}'
					and  f_state='有效'
			group by f_userinfo_id) s
			left join t_sellinggas s1 
			on s.f_userinfo_id=s1.f_userinfo_id and s.f_operate_date=s1.f_operate_date
			left join (select * from t_stairprice where f_state='有效') s2 
			on s1.f_price_id=s2.f_price_id
		group by s1.f_price_id,s2.f_gasproperties_type,s2.f_gasproperties
) s group by 	f_gasproperties_type,f_gasproperties
